@@ -15,15 +15,16 @@ from secretstorage.collection import Collection, create_collection, \
  get_all_collections, get_default_collection, get_any_collection, \
  get_collection_by_alias, search_items
 from secretstorage.item import Item
+from secretstorage.defines import DBUS_NOT_SUPPORTED, DBUS_EXEC_FAILED
 from secretstorage.exceptions import SecretStorageException, \
  SecretServiceNotAvailableException, LockedException, \
  ItemNotFoundException
 
-__version__ = '1.0.0'
+__version__ = '1.1.0'
 
 def dbus_init(main_loop=True, use_qt_loop=False):
 	"""Returns new SessionBus_. If `main_loop` is :const:`True`, registers
-	a main loop (Qt main loop if `use_qt_loop` is :const:`True`, otherwise
+	a main loop (PyQt5 main loop if `use_qt_loop` is :const:`True`, otherwise
 	GLib main loop).
 
 	.. _SessionBus: http://www.freedesktop.org/wiki/IntroductionToDBus#Buses
@@ -34,12 +35,18 @@ def dbus_init(main_loop=True, use_qt_loop=False):
 	"""
 	if main_loop:
 		if use_qt_loop:
-			from dbus.mainloop.qt import DBusQtMainLoop
+			from dbus.mainloop.pyqt5 import DBusQtMainLoop
 			DBusQtMainLoop(set_as_default=True)
 		else:
 			from dbus.mainloop.glib import DBusGMainLoop
 			DBusGMainLoop(set_as_default=True)
-	return dbus.SessionBus()
+	try:
+		return dbus.SessionBus()
+	except dbus.exceptions.DBusException as e:
+		if e.get_dbus_name() in (DBUS_NOT_SUPPORTED, DBUS_EXEC_FAILED):
+			raise SecretServiceNotAvailableException(
+				e.get_dbus_message())
+		raise
 
 # The functions below are provided for compatibility with old
 # SecretStorage versions (<= 0.2).
