@@ -4,25 +4,29 @@
 # License: BSD
 
 """Collection is a place where secret items are stored. Normally, only
-the default collection should be used (usually named "login"), but this
-module allows to use any registered collection.
+the default collection should be used, but this module allows to use any
+registered collection. Use :func:`get_default_collection` to get the
+default collection (and create it, if necessary).
 
 Collections are usually automatically unlocked when user logs in, but
 collections can also be locked and unlocked using
-:func:`Collection.lock` and :func:`Collection.unlock` methods (unlocking
+:meth:`Collection.lock` and :meth:`Collection.unlock` methods (unlocking
 requires showing the unlocking prompt to user and can be synchronous or
 asynchronous). Creating new items and editing existing ones is possible
 only in unlocked collection."""
 
 import dbus
-from secretstorage.defines import *
-from secretstorage.exceptions import *
+from secretstorage.defines import SS_PREFIX, SS_PATH, SECRETS
+from secretstorage.exceptions import LockedException, ItemNotFoundException
 from secretstorage.item import Item
-from secretstorage.util import *
+from secretstorage.util import bus_get_object, InterfaceWrapper, \
+ exec_prompt, exec_prompt_glib, format_secret, open_session, \
+ to_unicode
 
 COLLECTION_IFACE = SS_PREFIX + 'Collection'
 SERVICE_IFACE    = SS_PREFIX + 'Service'
 DEFAULT_COLLECTION = '/org/freedesktop/secrets/aliases/default'
+SESSION_COLLECTION = '/org/freedesktop/secrets/collection/session'
 
 class Collection(object):
 	"""Represents a collection."""
@@ -36,6 +40,7 @@ class Collection(object):
 			COLLECTION_IFACE)
 		self.collection_props_iface = InterfaceWrapper(collection_obj,
 			dbus.PROPERTIES_IFACE)
+		self.collection_props_iface.Get(COLLECTION_IFACE, 'Label')
 
 	def is_locked(self):
 		"""Returns :const:`True` if item is locked, otherwise
@@ -47,14 +52,14 @@ class Collection(object):
 		"""If collection is locked, raises
 		:exc:`~secretstorage.exceptions.LockedException`."""
 		if self.is_locked():
-			raise LockedException('Item is locked!')
+			raise LockedException('Collection is locked!')
 
 	def unlock(self, callback=None):
 		"""Requests unlocking the collection. If `callback` is specified,
 		calls it when unlocking is complete (see
 		:func:`~secretstorage.util.exec_prompt` description for
 		details) and returns a boolean representing whether the operation was
-		dismissed. Otherwise, uses asynchronous loop from GLib API."""
+		dismissed. Otherwise, uses loop from GLib API."""
 		service_obj = self.bus.get_object(SECRETS, SS_PATH)
 		service_iface = InterfaceWrapper(service_obj, SERVICE_IFACE)
 		prompt = service_iface.Unlock([self.collection_path], signature='ao')[1]
@@ -62,7 +67,7 @@ class Collection(object):
 			if callback:
 				exec_prompt(self.bus, prompt, callback)
 			else:
-				return exec_prompt_async_glib(self.bus, prompt)[0]
+				return exec_prompt_glib(self.bus, prompt)[0]
 		elif callback:
 			# We still need to call it.
 			callback(False, [])
@@ -116,6 +121,7 @@ class Collection(object):
 		if not self.session:
 			self.session = open_session(self.bus)
 		secret = format_secret(self.session, secret, content_type)
+		attributes = dbus.Dictionary(attributes, signature='ss')
 		properties = {
 			SS_PREFIX+'Item.Label': label,
 			SS_PREFIX+'Item.Attributes': attributes
@@ -128,7 +134,7 @@ def create_collection(bus, label, alias='', session=None):
 	"""Creates a new :class:`Collection` with the given `label` and `alias`
 	and returns it. This action requires prompting. If prompt is dismissed,
 	raises :exc:`~secretstorage.exceptions.ItemNotFoundException`. This is
-	asynchronous function, uses loop from GLib API."""
+	synchronous function, uses loop from GLib API."""
 	if not session:
 		session = open_session(bus)
 	properties = {SS_PREFIX+'Collection.Label': label}
@@ -138,7 +144,7 @@ def create_collection(bus, label, alias='', session=None):
 		alias)
 	if len(collection_path) > 1:
 		return Collection(bus, collection_path, session=session)
-	dismissed, unlocked = exec_prompt_async_glib(bus, prompt)
+	dismissed, unlocked = exec_prompt_glib(bus, prompt)
 	if dismissed:
 		raise ItemNotFoundException('Prompt dismissed.')
 	return Collection(bus, unlocked, session=session)
@@ -152,9 +158,38 @@ def get_all_collections(bus):
 	'Collections'):
 		yield Collection(bus, collection_path)
 
+def get_default_collection(bus, session=None):
+	"""Returns the default collection. If it doesn't exist,
+	creates it."""
+	try:
+		return Collection(bus)
+	except ItemNotFoundException:
+		return create_collection(bus, 'Default',
+		'default', session)
+
+def get_any_collection(bus):
+	"""Returns any collection, in the following order of preference:
+
+	- The default collection;
+	- The "session" collection (usually temporary);
+	- The first collection in the collections list."""
+	try:
+		return Collection(bus)
+	except ItemNotFoundException:
+		pass
+	try:
+		return Collection(bus, SESSION_COLLECTION)
+	except ItemNotFoundException:
+		pass
+	collections = list(get_all_collections(bus))
+	if collections:
+		return collections[0]
+	else:
+		raise ItemNotFoundException('No collections found.')
+
 def get_collection_by_alias(bus, alias):
-	"""Returns the collection with alias `alias`. If there is no such
-	collection, raises
+	"""Returns the collection with the given `alias`. If there is no
+	such collection, raises
 	:exc:`~secretstorage.exceptions.ItemNotFoundException`."""
 	service_obj = bus_get_object(bus, SECRETS, SS_PATH)
 	service_iface = dbus.Interface(service_obj, SERVICE_IFACE)
